Send patches - preferably formatted by git format-patch - to patches at archlinux32 dot org.
summaryrefslogtreecommitdiff
path: root/lib/libalpm/sync.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/libalpm/sync.c')
-rw-r--r--lib/libalpm/sync.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/libalpm/sync.c b/lib/libalpm/sync.c
index 25ac6dff..3eadfdf1 100644
--- a/lib/libalpm/sync.c
+++ b/lib/libalpm/sync.c
@@ -354,7 +354,7 @@ int sync_prepare(pmtrans_t *trans, pmdb_t *db_local, PMList *dbs_sync, PMList **
pmsyncpkg_t *sync = i->data;
list = pm_list_add(list, sync->pkg);
}
- trail = pm_list_new();
+ trail = _alpm_list_new();
/* Resolve targets dependencies */
EVENT(trans, PM_TRANS_EVT_RESOLVEDEPS_START, NULL, NULL);
@@ -660,9 +660,9 @@ int sync_commit(pmtrans_t *trans, pmdb_t *db_local)
if(trans_addtarget(tr, str) == -1) {
goto error;
}
/* using list_last() is ok because addtarget() adds the new target at the
* end of the tr->packages list */
- spkg = pm_list_last(tr->packages)->data;
+ spkg = _alpm_list_last(tr->packages)->data;
if(sync->type == PM_SYNC_TYPE_DEPEND) {
/* ORE
* if called from makepkg, reason should be set to PM_PKG_REASON_DEPEND */
@@ -660,9 +660,9 @@ int sync_commit(pmtrans_t *trans, pmdb_t *db_local)
goto error;
}
- /* using list_last() is ok because addtarget() adds the new target at the
+ /* using _alpm_list_last() is ok because addtarget() adds the new target at the
* end of the tr->packages list */